<?php
	//remove_theme_mods();

	/**
     *  Load Widgets classes
     */

    function cronus_autoload_widgets( $class_name )
    {
        if( preg_match( "/^cronus_widget_/", $class_name ) ){

            $class_file  = str_replace( '_', '-', str_replace( 'cronus_widget_', '', $class_name ) );
            $class_path  = get_stylesheet_directory() . '/widgets/cronus.' . esc_attr( $class_file ) . '.class.php';

            if( is_file( $class_path ) ){
                include_once  $class_path;
            }
        }
    }

    spl_autoload_register( 'cronus_autoload_widgets' );


    /**
	 *	Register Widgets
	 */

    function cronus_register_widgets()
	{
		register_widget( 'cronus_widget_post_categories' );
		register_widget( 'cronus_widget_post_tags' );
		register_widget( 'cronus_widget_post_meta' );
	}

	add_action( 'widgets_init', 'cronus_register_widgets' );


    /**
     *	Extends parent Theme Settings
     */

    function cronus_load_configs()
    {
		include_once get_stylesheet_directory() . '/cfgs/options.php';

	    include_once get_stylesheet_directory() . '/cfgs/main.php';
		include_once get_stylesheet_directory() . '/cfgs/pages/appearance/faq.php';
	    include_once get_stylesheet_directory() . '/cfgs/pages/customize/site-identity.php';
	    include_once get_stylesheet_directory() . '/cfgs/pages/customize/colors.php';
	    include_once get_stylesheet_directory() . '/cfgs/pages/customize/tempo.menu.php';
	    include_once get_stylesheet_directory() . '/cfgs/pages/customize/tempo.header.php';
	    include_once get_stylesheet_directory() . '/cfgs/pages/customize/tempo.breadcrumbs.php';
	    include_once get_stylesheet_directory() . '/cfgs/pages/customize/tempo.layout.php';

	    include_once get_stylesheet_directory() . '/cfgs/sidebars/cfgs.php';
	}

    add_action( 'tempo_load_cfgs', 'cronus_load_configs' );


    function cronus_setup_theme()
    {
        /**
         *  Internationalizations and Localization
         */

        load_child_theme_textdomain( 'cronus', get_stylesheet_directory() . '/languages' );
    }

    add_action( 'after_setup_theme', 'cronus_setup_theme', 1 );


    /**
     *	Include child Styles and Scripts
     */

    function cronus_enqueue_styles()
	{
		$ver = tempo_core::theme( 'Version' );

		// disable parent fontS AND SETTINGS
		wp_deregister_style( 'tempo-google-font-1' );
		wp_dequeue_style( 'tempo-google-font-1' );

		wp_deregister_style( 'tempo-settings-google-font-1' );
		wp_dequeue_style( 'tempo-settings-google-font-1' );


		$font = 'Montserrat:400,700';

		wp_register_style( 'tempo-google-font-1',           	'//fonts.googleapis.com/css?family=' . esc_attr( $font ), null, $ver );

		wp_register_style( 'cronus-typography',					get_stylesheet_directory_uri() . '/media/css/typography.min.css', null, $ver );
		wp_register_style( 'cronus-menu',						get_stylesheet_directory_uri() . '/media/css/menu.min.css', null, $ver );
		wp_register_style( 'cronus-header',						get_stylesheet_directory_uri() . '/media/css/header.min.css', null, $ver );
		wp_register_style( 'cronus-blog',						get_stylesheet_directory_uri() . '/media/css/blog.min.css', null, $ver );
		wp_register_style( 'cronus-forms',						get_stylesheet_directory_uri() . '/media/css/forms.min.css', null, $ver );
		wp_register_style( 'cronus-single',						get_stylesheet_directory_uri() . '/media/css/single.min.css', null, $ver );
		wp_register_style( 'cronus-comments',					get_stylesheet_directory_uri() . '/media/css/comments.min.css', null, $ver );
		wp_register_style( 'cronus-widgets',					get_stylesheet_directory_uri() . '/media/css/widgets.min.css', null, $ver );

		wp_register_style( 'cronus-footer',						get_stylesheet_directory_uri() . '/media/css/footer.min.css', null, $ver );
		wp_register_style( 'cronus-jetpack',					get_stylesheet_directory_uri() . '/media/css/jetpack.min.css', null, $ver );

		// include child font settings
		wp_register_style( 'tempo-settings-google-font-1', 		get_stylesheet_directory_uri() . '/media/css/settings-google-font-1.min.css', null, $ver );


		$dependency = array(
			'tempo-style',

			'tempo-google-font-1',

			'cronus-typography',
			'cronus-menu',
			'cronus-header',
			'cronus-blog',
			'cronus-forms',
			'cronus-single',
			'cronus-comments',
			'cronus-widgets',

			'cronus-footer',
			'cronus-jetpack',

			'tempo-settings-google-font-1'
		);

		wp_enqueue_style( 'cronus-style', 						get_stylesheet_uri(), $dependency, $ver );

		// Load the Internet Explorer specific stylesheet.
        wp_enqueue_style( 'cronus-ie',                       	get_stylesheet_directory_uri() . '/media/css/ie.min.css', null, $ver );
        wp_style_add_data( 'cronus-ie', 'conditional', 'IE' );


		wp_register_script( 'cronus-functions', 				get_stylesheet_directory_uri() . '/media/js/functions.js', array( 'jquery' ), $ver, true );
        wp_enqueue_script( 'cronus-functions' );
	}

	add_action( 'wp_enqueue_scripts', 'cronus_enqueue_styles' );



	{	////	LAYOUT


		/**
		 *	Define website Content width
		 */

		function cronus_content_width( $width ){
    		return 1140;
    	}

    	add_filter( 'tempo_content_width', 'cronus_content_width' );

		/**
		 *	Content Length
		 */

		function cronus_content_length( $length )
		{
			return 'col-lg-12';
		}

		add_filter( 'tempo_content_length', 'cronus_content_length' );


	    /**
	     *	Front Page Section Length
	     */

	    function cronus_front_page_section_length( $length )
	    {
	        $layout = new tempo_layout( 'front-page' );
	        return $layout -> classes();
	    }

	    add_filter( 'tempo_front_page_section_length', 'cronus_front_page_section_length' );


	    /**
	     *	Singular Post / Page Section Length
	     */

	    function cronus_singular_section_length( $length, $post_id )
	    {
	    	if( empty( $post_id ) )
	    		return;

	    	$post = get_post( $post_id );

	        $layout = new tempo_layout( $post -> post_type );
	        return $layout -> classes();
	    }

	    add_filter( 'tempo_page_section_length', 'cronus_singular_section_length', 10, 2 );
	    add_filter( 'tempo_single_section_length', 'cronus_singular_section_length', 10, 2 );

	    /**
	     *	Loop Section Length + Blog View Class
	     */

	    function cronus_loop_section_length( $layout )
	    {
	        $layout = new tempo_layout();
	        return esc_attr( $layout -> classes() . ' tempo-blog-' . tempo_options::get( 'blog-view' ) );
	    }

	    add_filter( 'tempo_loop_section_length', 'cronus_loop_section_length' );



	    ///// SIDEBARS ACTIONS /////

	    /**
	     *	Left Sidebars
	     */

	    function cronus_left_sidebar( $slug, $name )
	    {
	    	if( is_404() )
	    		return;

		    /**
		     *	get sidebar
		     */

	    	$layout = new tempo_layout( $name );

	    	if( is_singular() && !( is_front_page() || is_home() ) ){
	    		global $post;

	    		$layout = new tempo_layout( $name );
	    	}

			// left sidebar
	        $layout -> sidebar( 'left' );
	    }

	    add_action( 'get_template_part_templates/section/before', 'cronus_left_sidebar', 10, 2 );

	    /**
	     *	Right Sidebars
	     */

	    function cronus_right_sidebar( $slug, $name )
	    {
	    	if( is_404() )
	    		return;

		    /**
		     *	get sidebar
		     */

	    	$layout = new tempo_layout( $name );

	    	if( is_singular() && !( is_front_page() || is_home() ) ){
	    		global $post;

	    		$layout = new tempo_layout( $name );
	    	}

	    	// right sidebar
	        $layout -> sidebar( 'right' );
	    }

	    add_action( 'get_template_part_templates/section/after', 'cronus_right_sidebar', 10, 2 );
	}


	{	////	HEADER


		/**
    	 *	Disable default parent custom style
    	 */

    	function cronus_not_has_header()
	    {
	    	return !tempo_has_header();
	    }

 		add_filter( 'tempo_site_identity_style', 'cronus_not_has_header' );
    	add_filter( 'tempo_menu_style', 'cronus_not_has_header' );


    	function cronus_customize_js_files( $files )
	    {
	    	$files[ 'cronus-customize' ] = get_stylesheet_directory_uri() . '/media/admin/js/customize.js';

	    	return $files;
	    }

    	add_filter( 'tempo_customize_js_files', 'cronus_customize_js_files' );


		function cronus_mix_height()
		{
	    	$headline       = tempo_options::get( 'header-headline' );
    		$description    = tempo_options::get( 'header-description' );

			$btn_1 			= tempo_options::get( 'header-btn-1' );
    		$btn_2 			= tempo_options::get( 'header-btn-2' );

    		return ( $headline || $description ) && ( $btn_1 || $btn_2 );
		}

		function cronus_header_height( $height )
		{
			if( cronus_mix_height() )
        		$height = tempo_options::get( 'header-text-space' ) + tempo_options::get( 'header-btns-space' );

        	return $height;
		}

		add_filter( 'tempo_header_height', 'cronus_header_height' );

		/**
		 *  Flex Container - get vertical position from plugin settings
		 */

		function cronus_flex_container_class( $valign )
		{
			if( empty( $valign ) && $mix_height = cronus_mix_height() )
				$valign = 'tempo-valign-' . tempo_options::get( 'header-text-vertical-align' );

			return esc_attr( trim( $valign ) );
		}

		add_filter( 'tempo_flex_container_class', 'cronus_flex_container_class' );

		/**
		 *	Flex text Container - get style
		 */
		function cronus_header_text_wrapper_style( $style )
		{
			if( cronus_mix_height() )
		        $style	= 'height: ' . absint( tempo_options::get( 'header-text-space' ) ) . 'px;';

		    return $style;
		}

		add_filter( 'tempo_header_text_wrapper_style', 'cronus_header_text_wrapper_style' );

		/**
		 *  Flex Item - get horizontal position from plugin settings
		 */

		function cronus_flex_item_class( $align )
		{
			if( empty( $align ) )
				$align = 'tempo-align-' . tempo_options::get( 'header-horizontal-align' );

			return esc_attr( trim( $align ) );
		}

		add_filter( 'tempo_flex_item_class', 'cronus_flex_item_class' );
	}


	/**
	 *	Comments Submit button Classes
	 */

	function cronus_submi_comment_class( $classes )
	{
		return 'tempo-btn btn-hover-empty icon-left';
	}

	add_filter( 'tempo_submi_comment_class', 'cronus_submi_comment_class' );

	/**
	 *	Footer Social
	 */

	function cronus_footer_social( $slug, $name )
    {
    	tempo_get_template_part( 'templates/footer/prepend-social' );
    }

    add_action( 'get_template_part_templates/footer/prepend', 'cronus_footer_social', 10, 2 );


    /**
     *	Footer Dark Sidebars
     */

	function cronus_merge_footer_dark_sidebars( $cfgs )
	{
        $cfgs[ 'footer' ][ 'footer-dark' ] = array(
            'id'            => 'footer-dark',
            'name'          => __( 'Footer Dark Side' , 'cronus' ),
            'description'   => __( 'Inside of the Sidebar the widgets will be arranged in 4 columns.' , 'cronus' ),
            'before_widget' => '<div id="%1$s" class="widget %2$s col-xs-6 col-sm-6 col-md-3 col-lg-3">',
            'after_widget'  => '</div>',
            'before_title'  => '<h5 class="widget-title">',
            'after_title'   => '</h5>'
        );

	    return $cfgs;
	}

	add_filter( 'tempo_merge_sidebars', 'cronus_merge_footer_dark_sidebars' );
?>
